Documentation
¶
Overview ¶
Package types contains shareable types between sub-modules.
Package types contains shareable types between sub-modules.
Package types contains shareable types between sub-modules.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AdminsConfig ¶
type AdminsConfig struct {
Admins []string `json:"admins"`
}
type BotsConfig ¶
type BotsConfig struct {
Personality PersonalityConfig `json:"personality"`
Listeners []ListenerConfig `json:"listeners"`
}
type BrainConfig ¶
type CommunicationChannel ¶
type CommunicationChannel struct {
Data interface{}
}
type ListenerConfig ¶
type ListenerConfig struct {
Id string `json:"id"`
Type string `json:"type"`
Enabled bool `json:"enabled"`
Settings map[string]string `json:"settings"`
}
func (*ListenerConfig) Get ¶
func (self *ListenerConfig) Get(name, fallback string) string
Get safely gets an optional config key or falls back to a default value.
type PersonalityConfig ¶
type PersonalityConfig struct {
Name string `json:"name"`
Brain BrainConfig `json:"brain"`
}
type ReplyAnswer ¶
ReplyAnswer is an outgoing message to a listener to send to a user.
type ReplyRequest ¶
type ReplyRequest struct {
Listener string
GroupChat bool
BotUsername string
Username string
Message string
}
ReplyRequest is a channel for a listener requesting a response for a user.
type Stopped ¶
type Stopped struct {
ListenerId string
}
Stopped is a message from a listener communicating that it has been stopped.
type UservarsConfig ¶
Click to show internal directories.
Click to hide internal directories.